==> vmaid-2.1.7.tar.gz: vmaid-2.1.7/w32loader/w32stc.h <==
/*
    w32loader
    copyright (c) 1998-2007 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/
#ifndef __W32STC_H__
#define __W32STC_H__


/* ja:スタティックコントロール */
#define SS_LEFT            0x00000000
#define SS_CENTER          0x00000001
#define SS_RIGHT           0x00000002
#define SS_ICON            0x00000003
#define SS_BLACKRECT       0x00000004
#define SS_GRAYRECT        0x00000005
#define SS_WHITERECT       0x00000006
#define SS_BLACKFRAME      0x00000007
#define SS_GRAYFRAME       0x00000008
#define SS_WHITEFRAME      0x00000009
#define SS_USERITEM        0x0000000a
#define SS_SIMPLE          0x0000000b
#define SS_LEFTNOWORDWRAP  0x0000000c
#define SS_OWNERDRAW       0x0000000d
#define SS_BITMAP          0x0000000e
#define SS_ENHMETAFILE     0x0000000f
#define SS_ETCHEDHORZ      0x00000010
#define SS_ETCHEDVERT      0x00000011
#define SS_ETCHEDFRAME     0x00000012
#define SS_TYPEMASK        0x0000001f
#define SS_REALSIZECONTROL 0x00000040
#define SS_NOPREFIX        0x00000080
#define SS_NOTIFY          0x00000100
#define SS_CENTERIMAGE     0x00000200
#define SS_RIGHTJUST       0x00000400
#define SS_REALSIZEIMAGE   0x00000800
#define SS_SUNKEN          0x00001000
#define SS_EDITCONTROL     0x00002000
#define SS_ENDELLIPSIS     0x00004000
#define SS_PATHELLIPSIS    0x00008000
#define SS_WORDELLIPSIS    0x0000c000
#define SS_ELLIPSISMASK    0x0000c000
#define STM_SETICON  0x0170
#define STM_GETICON  0x0171
#define STM_SETIMAGE 0x0172
#define STM_GETIMAGE 0x0173
#define STN_CLICKED 0
#define STN_DBLCLK  1
#define STN_ENABLE  2
#define STN_DISABLE 3


#endif /* not __W32STC_H__ */

==> vmaid-2.2.0.tar.gz: vmaid-2.2.0/w32loader/w32stc.h <==
/*
    w32loader
    copyright (c) 1998-2008 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef __W32STC_H__
#define __W32STC_H__


G_BEGIN_DECLS


/* ja:スタティックコントロール */
#define SS_LEFT            0x00000000
#define SS_CENTER          0x00000001
#define SS_RIGHT           0x00000002
#define SS_ICON            0x00000003
#define SS_BLACKRECT       0x00000004
#define SS_GRAYRECT        0x00000005
#define SS_WHITERECT       0x00000006
#define SS_BLACKFRAME      0x00000007
#define SS_GRAYFRAME       0x00000008
#define SS_WHITEFRAME      0x00000009
#define SS_USERITEM        0x0000000a
#define SS_SIMPLE          0x0000000b
#define SS_LEFTNOWORDWRAP  0x0000000c
#define SS_OWNERDRAW       0x0000000d
#define SS_BITMAP          0x0000000e
#define SS_ENHMETAFILE     0x0000000f
#define SS_ETCHEDHORZ      0x00000010
#define SS_ETCHEDVERT      0x00000011
#define SS_ETCHEDFRAME     0x00000012
#define SS_TYPEMASK        0x0000001f
#define SS_REALSIZECONTROL 0x00000040
#define SS_NOPREFIX        0x00000080
#define SS_NOTIFY          0x00000100
#define SS_CENTERIMAGE     0x00000200
#define SS_RIGHTJUST       0x00000400
#define SS_REALSIZEIMAGE   0x00000800
#define SS_SUNKEN          0x00001000
#define SS_EDITCONTROL     0x00002000
#define SS_ENDELLIPSIS     0x00004000
#define SS_PATHELLIPSIS    0x00008000
#define SS_WORDELLIPSIS    0x0000c000
#define SS_ELLIPSISMASK    0x0000c000
#define STM_SETICON  0x0170
#define STM_GETICON  0x0171
#define STM_SETIMAGE 0x0172
#define STM_GETIMAGE 0x0173
#define STN_CLICKED 0
#define STN_DBLCLK  1
#define STN_ENABLE  2
#define STN_DISABLE 3


G_END_DECLS


#endif /* not __W32STC_H__ */
